# eric7.Preferences.ConfigurationPages.EditorCallTipsJediPage

Module implementing the Jedi Calltips configuration page.

### Global Attributes

None

### Classes

EditorCallTipsJediPage | Class implementing the Jedi Calltips configuration page.

### Functions

create | Module function to create the configuration page.

## EditorCallTipsJediPage

Class implementing the Jedi Calltips configuration page.

### Derived from

ConfigurationPageBase, Ui_EditorCallTipsJediPage

### Class Attributes

None

### Class Methods

None

### Methods

EditorCallTipsJediPage | Constructor
save | Public slot to save the Jedi Calltips configuration.

### Static Methods

None

#### EditorCallTipsJediPage (Constructor)

EditorCallTipsJediPage()

Constructor

#### EditorCallTipsJediPage.save

save()

Public slot to save the Jedi Calltips configuration.

Up

## create

create(_dlg)

Module function to create the configuration page.

_dlg (ConfigurationDialog)
  reference to the configuration dialog (unused)

Return:
  reference to the instantiated page

Return Type:
  ConfigurationPageBase

Up